<?php

// Hook into `admin_menu` and provide callback function name
add_action( 'admin_menu', 'envato_affiliate_setting_helper' );

// In the callback function provide settings configuration array to the Helper class 
function envato_affiliate_setting_helper() {

	// Require Settings Helper Class
	require_once 'class-boo-settings-helper.php';

	// Create Config Array
	$settings_config_array             = array();
	$settings_config_array['prefix']   = 'ieaff_';
	$settings_config_array['tabs']     = true;
	$settings_config_array['menu']     = array(
		'page_title' => __( 'Envato Affiliate Settings', 'envato-affiliate' ),
		'menu_title' => __( 'Envato Affiliate', 'envato-affiliate' ),
		'capability' => 'manage_options',
		'slug'       => 'en-aff',
		'icon'       => 'dashicons-performance',
		'position'   => 10,
		'parent'     => 'options-general.php',
		'submenu'    => true,
	);
	$settings_config_array['sections'] = array(
		array(
			'id'    => 'general_section',
			'title' => __( 'General Settings', 'envato-affiliate' ),
			'desc'  => __( 'These are general settings for Envato Affiliate', 'envato-affiliate' ),
		),
		array(
			'id'    => 'advance_section',
			'title' => __( 'Advanced Settings', 'envato-affiliate' ),
			'desc'  => __( 'These are advance settings for Envato Affiliate', 'envato-affiliate' )
		)
	);
	$settings_config_array['fields']   = array(
		'general_section' => array(

			array(
				'id'    => 'envatoaff_enabled',
				'label' => __( 'Enable/Disable Plugin', 'envato-affiliate' ),
				'desc'  => __( 'Quickly turn on / off the effects of the plugin without having to disable it.', 'envato-affiliate' ),
				'type'  => 'checkbox',
				'default'     => '1',
			),

			array(
				'id'    => 'ir_market_url',
				'label' => __( 'Impact Radius Market', 'envato-affiliate' ),
				'placeholder'       => 'https://1.envato.market/c/1386563/289206/4415',
				'type'  => 'url',
				'desc'    => __( 'Your personal tracking link available from `https://member.impactradius.com/`', 'envato-affiliate' ),
			),

			array(
				'id'      => 'envatoaff_content',
				'label'   => __( 'Replace URL\'s In', 'envato-affiliate' ),
				'desc'    => __( 'Choose how deep Envato affiliate should look to replace URLs.', 'envato-affiliate' ),
				'type'    => 'radio',
				'options' => array(
					'post' => __( 'Post Content Only', 'envato-affiliate' ),
					'meta' => __( 'Post Content And Excerpt', 'envato-affiliate' ),
					'all'  => __( 'Post Content, Excerpts And Comments', 'envato-affiliate' ),
				),
				'default' => 'post'
			),			
		),
		'advance_section' => array(

			array(
				'id'    => 'base64_encode',
				'label' => __( 'Link Encoding', 'envato-affiliate' ),
				'desc'  => __( 'Masking Link Encoding with base64', 'envato-affiliate' ),
				'type'  => 'checkbox',
				'default'     => '1',
			),
			array(
				'id'      => 'redirect_page',
				'label'   => __( 'Redirect Page', 'envato-affiliate' ),
				'desc'    => __( 'Select a Page used for Redirect', 'envato-affiliate' ),
				'type'    => 'pages',
				'options' => array(
					'post_type' => 'post'
				),
			),
			array(
				'id'          => 'waiting_time',
				'label'       => __( 'Waiting Time', 'envato-affiliate' ),
				'desc'        => __( 'Redirect page countdown time.', 'envato-affiliate' ),
				'options'     => array(
					'min'  => 0,
					'max'  => 30,
					'step' => '1',
				),
				'type'        => 'number',
				'default'     => '5',
			),
		)
	);

	// Pass Config Array to Class Constructor
	$settings_helper = new Boo_Settings_Helper( $settings_config_array );

}